==> fparser_0.0.11.orig.tar.xz: fparser-0.0.11/README.md <==
# News #

  * 15/05/2020 Version 0.0.11 released. See the [CHANGELOG](CHANGELOG.md)
    for details.
  * 18/11/2019 Version 0.0.10 released. See the [CHANGELOG](CHANGELOG.md)
    for details.
  * 04/11/2019 Version 0.0.9 released. See the [CHANGELOG](CHANGELOG.md)
    for details.
  * 03/12/2018 Version 0.0.8 released. See the [CHANGELOG](CHANGELOG.md)
    for details.
  * 23/04/2018 Version 0.0.7 released. See the [CHANGELOG](CHANGELOG.md)
    for details.
  * 22/03/2017 Version 0.0.2 released. Documentation made available
    on [ReadTheDocs](http://fparser.readthedocs.io).
  * 16/01/2017 Parser code extracted from F2PY project to form the
    base of the fparser project.

# Introduction #

This project is based upon the Fortran (77..2003) parser originally
developed by Pearu Peterson for the F2PY project,
[www.f2py.com](http://www.f2py.com).

# Obtaining #

fparser is available from the [Python Package Index](https://pypi.python.org/pypi/fparser).
It may also be cloned from [github](https://github.com/stfc/fparser). Alternatively, github provides
tarballs for each of the [releases](https://github.com/stfc/fparser/releases).

# Documentation #

The documentation for fparser is hosted on [ReadTheDocs](http://fparser.readthedocs.io).

# Code Metrics #

[![Build Status](https://travis-ci.org/stfc/fparser.svg?branch=master)](https://travis-ci.org/stfc/fparser)
[![Coverage Status](https://coveralls.io/repos/github/stfc/fparser/badge.svg?branch=master)](https://coveralls.io/github/stfc/fparser?branch=master)
[![Code Health](https://landscape.io/github/stfc/fparser/master/landscape.svg?style=flat)](https://landscape.io/github/stfc/fparser/master)
[![Documentation Status](https://readthedocs.org/projects/fparser/badge/?version=stable)](http://fparser.readthedocs.io/en/stable/?badge=stable)

# See also #

[www.f2py.com](http://www.f2py.com).

==> fparser_0.0.16.orig.tar.xz: fparser-0.0.16/README.md <==
# News #

  * 16/06/2022 Version 0.0.16 released. See the [CHANGELOG](CHANGELOG.md)
    for details.
  * 30/05/2022 Version 0.0.15 released. See the [CHANGELOG](CHANGELOG.md)
    for details.
  * 10/03/2022 Version 0.0.14 released. See the [CHANGELOG](CHANGELOG.md)
    for details.
  * 02/11/2021 Version 0.0.13 released. See the [CHANGELOG](CHANGELOG.md)
    for details.
  * 26/04/2021 Version 0.0.12 released. See the [CHANGELOG](CHANGELOG.md)
    for details.
  * 15/05/2020 Version 0.0.11 released. See the [CHANGELOG](CHANGELOG.md)
    for details.
  * 18/11/2019 Version 0.0.10 released. See the [CHANGELOG](CHANGELOG.md)
    for details.
  * 04/11/2019 Version 0.0.9 released. See the [CHANGELOG](CHANGELOG.md)
    for details.
  * 03/12/2018 Version 0.0.8 released. See the [CHANGELOG](CHANGELOG.md)
    for details.
  * 23/04/2018 Version 0.0.7 released. See the [CHANGELOG](CHANGELOG.md)
    for details.
  * 22/03/2017 Version 0.0.2 released. Documentation made available
    on [ReadTheDocs](http://fparser.readthedocs.io).
  * 16/01/2017 Parser code extracted from F2PY project to form the
    base of the fparser project.

# Introduction #

This project is based upon the Fortran (77..2003) parser originally
developed by Pearu Peterson for the F2PY project,
[www.f2py.com](http://www.f2py.com). It provides a parser for Fortran
source code implemented purely in Python with minimal dependencies.

# Obtaining #

fparser is available from the [Python Package Index](https://pypi.python.org/pypi/fparser).
It may also be cloned from [github](https://github.com/stfc/fparser). Alternatively, github provides
tarballs for each of the [releases](https://github.com/stfc/fparser/releases).

# Documentation #

The documentation for fparser is hosted on [ReadTheDocs](http://fparser.readthedocs.io).

# Code Metrics #

![fparser unit tests](https://github.com/stfc/fparser/workflows/fparser%20unit%20tests/badge.svg)
[![codecov](https://codecov.io/gh/stfc/fparser/branch/master/graph/badge.svg?token=x0abs66TST)](https://codecov.io/gh/stfc/fparser)
[![Documentation Status](https://readthedocs.org/projects/fparser/badge/?version=stable)](http://fparser.readthedocs.io/en/stable/?badge=stable)

# See also #

[www.f2py.com](http://www.f2py.com).
